# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-01-19 13:25
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('modeltranslation', '0007_auto_20160119_1351'),
    ]

    operations = [
        migrations.AlterIndexTogether(
            name='fieldtranslation',
            index_together=set([('source_md5',), ('lang', 'is_fuzzy'), ('module', 'model', 'object_id', 'lang', 'field', 'is_fuzzy')]),
        ),
    ]
