{% extends "admin/index.html" %}
{% load i18n %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo;
{% for app in app_list %}
{{ app.name }}
{% endfor %}
</div>
{% endblock %}
{% endif %}

{% block sidebar %}{% endblock %}

{% block content %}
<div>
  <ul class="object-tools">
    <li>
      <a title="{% trans 'Admin translations' %}" href="{% url 'modeltranslation:admin_url' %}" class="btn">
       {% trans 'Admin translations' %}
      </a>
    </li>
    <li>
      <a title="{% trans 'Update translations' %}" href="{% url 'modeltranslation:update_translations_url' %}" class="btn">
        {% trans 'Update translations' %}
      </a>
    </li>
  </ul>
</div>
  {{block.super}}
{% endblock content %}
