{% extends "modeltranslation/admin/admin.html" %}

{% load static from staticfiles %}
{% load thumbnail %}
{% load i18n %}

{% block custom-css %}
	{{ block.super }}
	<link rel="stylesheet" href="{% static 'css/modeltranslation/search.css' %}" />
{% endblock %}

{% block head_title %}
	Admin translations
{% endblock %}

{% block breadcrumb_element %}
	{{ block.super }}
	<li class="">
		<span class="divider">/</span>
		<a href="{% url 'modeltranslation:update_translations_url' %}" class="first">Translations update</a>
	</li>
{% endblock breadcrumb_element %}

{% block body %}
	<div id="body-content" class="span12">
		<div id="content-title" class="page-header">
			<h1>
				{%block title %}
					Success
				{% endblock %}
			</h1>
		</div>

		<div id="content" class="">
			{% block content %}
				{{num_translations}} texts has been translated.
				<div class="translation_admin_actions">
					<a href="{% url 'modeltranslation:admin_url' %}" class="btn"><span class="fa fa-reload-alt"></span> Back</a>
				</div>
			{% endblock content %}
		</div>
	</div>
{% endblock %}
